@@ -2,7 +2,7 @@ package Net::EPP::Server;
 # ABSTRACT: A simple EPP server implementation.
 use Carp;
 use Crypt::OpenSSL::Random;
-use DateTime::Format::ISO8601;
+use DateTime;
 use Digest::SHA qw(sha512_hex);
 use IO::Socket::SSL;
 use List::Util qw(any none);
@@ -714,7 +714,7 @@ Net::EPP::Server - A simple EPP server implementation.
 
 =head1 VERSION
 
-version 0.001
+version 0.002
 
 =head1 SYNOPSIS
 
@@ -797,7 +797,7 @@ version 0.001
         } else {
             return OK;
 
-        }  
+        }
     }
 
 =head1 INTRODUCTION
@@ -807,7 +807,7 @@ Provisioning Protocol (EPP)|https://www.rfc-editor.org/info/std69> servers.
 
 It implements the TLS/TCP transport described in L<RFC 5734|https://www.rfc-editor.org/info/rfc5734>,
 and the L<EPP Server State Machine|https://www.rfc-editor.org/rfc/rfc5730.html#:~:text=Figure%201:%20EPP%20Server%20State%20Machine>
-described in Section 2 of L<RFC 5730|https://www.rfc-editor.org/rfc/rfc5730.html>.
+described in L<Section 2 of RFC 5730|https://www.rfc-editor.org/rfc/rfc5730.html>.
 
 =head1 SERVER CONFIGURATION
 
@@ -839,7 +839,10 @@ file can include other XSD files using C<E<lt>importE<gt>>.
 
 You implement the business logic of your EPP server by specifying callbacks that
 are invoked for certain events. These come in two flavours: I<events> and
-C<commands>.
+I<commands>.
+
+All event handlers receive a hash containing one or more arguments that are
+described below.
 
 =head2 C<frame_received>
 
@@ -857,7 +860,7 @@ C<E<lt>helloE<gt>> and C<E<lt>logoutE<gt>>commands.
 
 C<Net::EPP::Server> takes care of handling session management, but this event
 handler will be called once a C<E<lt>logoutE<gt>> command has been successfully
-processed, but before the client connection has been closed. The C<session>
+processed, and before the client connection has been closed. The C<session>
 argument will contain a hashref of the session (see below).
 
 =head2 C<hello>
@@ -876,7 +879,7 @@ will be used.
 =item * C<lang> (OPTIONAL) - an arrayref containing language codes. It not
 provided, C<en> will be used as the only supported language.
 
-=item * C<objects> (REQUIRED) - an arrayref of namespace URIs for 
+=item * C<objects> (REQUIRED) - an arrayref of namespace URIs for
 
 =back
 
@@ -920,7 +923,7 @@ All command handlers receive a hash containing the following arguments:
 
 =over
 
-=item * C<$server> - the server.
+=item * C<server> - the server.
 
 =item * C<event> - the name of the command.
 
@@ -939,8 +942,8 @@ element of the response.
 
 =head3 SESSION PARAMETERS
 
-As mentioned above, the C<$args{session}> parameter is a hashref which contains
-information about the session. It contains the following:
+As mentioned above, the C<session> parameter is a hashref which contains
+information about the session. It contains the following values:
 
 =over
 
@@ -954,12 +957,12 @@ information about the session. It contains the following:
 
 =item * C<lang> - the language specified at login.
 
-=item * C<objects> - the object URI(s) specified at login.
+=item * C<objects> - an arrayref of the object URI(s) specified at login.
 
-=item * C<lang> - the extension URI(s) specified at login.
+=item * C<extensions> - an arrayref of the extension URI(s) specified at login.
 
-=item * C<client_cert> - information about the client certificate (if any). This
-is a hashref which looks something like this:
+=item * C<client_cert> - a hashref containing information about the client
+certificate (if any), which looks something like this:
 
     {
       'issuer' => $dnref,
@@ -1008,8 +1011,8 @@ Example:
         }
     }
 
-C<Net::EPP::Server> will construct a standard EPP response frame using the result
-code and send it to the client.
+C<Net::EPP::Server> will construct a standard EPP response frame using the
+result code and send it to the client.
 
 =head4 2. RESULT CODE + MESSAGE
 
@@ -1030,8 +1033,8 @@ then the second can be a message. Example:
         }
     }
 
-C<Net::EPP::Server> will construct a standard EPP response frame using the result
-code and message, and send it to the client.
+C<Net::EPP::Server> will construct a standard EPP response frame using the
+result code and message, and send it to the client.
 
 =head4 3. RESULT CODE + XML ELEMENTS
 
@@ -1053,8 +1056,8 @@ Example:
         );
     }
 
-C<Net::EPP::Server> will construct a standard EPP response frame using the result
-code and supplied elements which will be imported and inserted into the
+C<Net::EPP::Server> will construct a standard EPP response frame using the
+result code and supplied elements which will be imported and inserted into the
 appropriate positions, and send it to the client.
 
 =head4 4. L<XML::LibXML::Document> OBJECT
@@ -1064,8 +1067,8 @@ back to the client verbatim.
 
 =head3 EXCEPTIONS
 
-C<Net::EPP::Server> will catch any exceptions thrown by the command handler, will
-C<carp($@)>, and then send a C<2400> result code back to the client.
+C<Net::EPP::Server> will catch any exceptions thrown by the command handler,
+will C<carp($@)>, and then send a C<2400> result code back to the client.
 
 =head1 UTILITY METHODS
 
@@ -1076,12 +1079,12 @@ described by C<%args>, which should contain the following:
 
 =over
 
-=item * C<code> (OPTIONAL) - the result code. See L<Net::EPP::ResponseCodes>. If
-not provided, C<1000> will be used.
+=item * C<code> (OPTIONAL) - the result code. See L<Net::EPP::ResponseCodes>.
+If not provided, C<1000> will be used.
 
 =item * C<msg> - a human-readable error message. If not provided, the string
-C<"Command completed successfully."> will be used if C<code> is less than C<2000>,
-and C<"Command failed."> if C<code> is C<2000> or higher.
+C<"Command completed successfully."> will be used if C<code> is less than
+C<2000>, and C<"Command failed."> if C<code> is C<2000> or higher.
 
 =item * C<resData> (OPTIONAL) - if defined, an empty C<E<lt>resDataE<gt>>
 element will be added to the frame.
@@ -1097,8 +1100,8 @@ change its contents as needed.
 
 =head2 C<generate_error(%args)>
 
-This method is identical to C<generate_response()> except the default value for
-the C<code> parameter is C<2400>, indicating that the command failed for
+This method is identical to C<generate_response()> except the default value
+for the C<code> parameter is C<2400>, indicating that the command failed for
 unspecified reasons.
 
 =head2 C<generate_svTRID()>
